==> nextcloud-10.0.2.tar.bz2: nextcloud/settings/l10n/ro.js <==
OC.L10N.register(
    "settings",
    {
    "Enabled" : "Activat",
    "Not enabled" : "Dezactivat",
    "Wrong password" : "Parolă greșită",
    "Saved" : "Salvat",
    "No user supplied" : "Nu a fost furnizat niciun utilizator",
    "Unable to change password" : "Imposibil de schimbat parola",
    "Authentication error" : "Eroare la autentificare",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Furnizează o parolă administrativă de recuperare, altfel toate datele utilizatorilor vor fi pierdute",
    "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
    "Federated Cloud Sharing" : "Partajare federalizata cloud",
    "Migration Completed" : "Migrare încheiată",
    "Group already exists." : "Grupul există deja.",
    "Unable to add group." : "Nu se poate adăuga grupul.",
    "Unable to delete group." : "Nu se poate șterge grupul.",
    "test email settings" : "verifică setările de e-mail",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
    "Email sent" : "Mesajul a fost expediat",
    "You need to set your user email before being able to send test emails." : "Trebuie să îți setezi emailul de utilizator înainte de a putea să trimiți emailuri.",
    "Invalid request" : "Cerere eronată",
    "Invalid mail address" : "Adresa mail invalidă",
    "A user with that name already exists." : "Există deja un utilizator cu acest nume.",
    "Unable to create user." : "Imposibil de creat utilizatorul.",
    "Your %s account was created" : "Contul tău %s a fost creat",
    "Unable to delete user." : "Imposibil de șters utilizatorul.",
    "Unable to change full name" : "Nu s-a putut schimba numele complet",
    "Your full name has been changed." : "Numele tău complet a fost schimbat.",
    "Forbidden" : "Interzis",
    "Invalid user" : "Utilizator invalid",
    "Unable to change mail address" : "Nu s-a putut schimba adresa email",
    "Email saved" : "E-mail salvat",
    "Couldn't remove app." : "Nu s-a putut înlătura aplicația.",
    "Admins can't remove themself from the admin group" : "Administratorii nu se pot șterge singuri din grupul adminnistrativ",
    "Unable to add user to group %s" : "Nu s-a putut adăuga utilizatorul în grupul %s",
    "Unable to remove user from group %s" : "Nu s-a putut elimina utilizatorul din grupul %s",
    "Couldn't update app." : "Aplicaţia nu s-a putut actualiza.",
    "Add trusted domain" : "Adaugă domeniu de încredere",
    "Migration in progress. Please wait until the migration is finished" : "Migrare în progres. Așteaptă până când migrarea este finalizată",
    "Migration started …" : "Migrarea a început...",
    "Sending..." : "Se expediază...",
    "Official" : "Oficial",
    "All" : "Toate ",
    "_You have %n app update pending_::_You have %n app updates pending_" : ["Ai %n actualizare de aplicație în așteptare","Ai %n actualizări de aplicație în așteptare","Ai %n actualizări de aplicație în așteptare"],
    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
    "Please wait...." : "Aşteptaţi vă rog....",
    "Error while disabling app" : "Eroare în timpul dezactivării aplicației",
    "Disable" : "Dezactivați",
    "Enable" : "Activare",
    "Error while enabling app" : "Eroare în timpul activării applicației",
    "Updating...." : "Actualizare în curs....",
    "Error while updating app" : "Eroare în timpul actualizării aplicaţiei",
    "Updated" : "Actualizat",
    "Uninstalling ...." : "Dezinstalaza ....",
    "Error while uninstalling app" : "Eroare la dezinstalarea aplicației",
    "Uninstall" : "Dezinstalați",
    "App update" : "Actualizare aplicație",
    "Approved" : "Aprobat",
    "Experimental" : "Experimental",
    "Disconnect" : "Deconectare",
    "Valid until {date}" : "Valabil până la {date}",
    "Delete" : "Șterge",
    "Select a profile picture" : "Selectează o imagine de profil",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Groups" : "Grupuri",
    "Unable to delete {objName}" : "Nu s-a putut șterge {objName}",
    "Error creating group: {message}" : "Eroare la crearea grupului: {message}",
    "A valid group name must be provided" : "Trebuie furnizat un nume de grup valid",
    "deleted {groupName}" : "{groupName} s-a șters",
    "undo" : "Anulează ultima acțiune",
    "never" : "niciodată",
    "deleted {userName}" : "{userName} șters",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Schimbarea parolei va rezulta în pierderea datelor deoarece recuperarea acestora nu este disponibilă pentru acest utilizator",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "Error creating user: {message}" : "Eroare la crearea utilizatorului: {message}",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "A valid email must be provided" : "Trebuie furnizată o adresă email validă",
    "__language_name__" : "Română",
    "Unlimited" : "Nelimitată",
    "Personal info" : "Informații personale",
    "Sessions" : "Sesiuni",
    "App passwords" : "Parole aplicații",
    "Sync clients" : "Sincronizează clienții",
    "None" : "Niciuna",
    "Login" : "Autentificare",
    "NT LAN Manager" : "NT LAN Manager",
    "Email server" : "Server de email",
    "Open documentation" : "Deschide documentația",
    "Send mode" : "Modul de expediere",
    "Encryption" : "Încriptare",
    "From address" : "De la adresa",
    "mail" : "poștă",
    "Authentication method" : "Modul de autentificare",
    "Authentication required" : "Autentificare necesară",
    "Server address" : "Adresa server-ului",
    "Port" : "Portul",
    "Credentials" : "Detalii de autentificare",
    "SMTP Username" : "Nume utilizator SMTP",
    "SMTP Password" : "Parolă SMTP",
    "Store credentials" : "Stochează datele de autentificare",
    "Test email settings" : "Verifică setările de e-mail",
    "Send email" : "Expediază mesajul",
    "Server-side encryption" : "Criptare la nivel de server",
    "Enable server-side encryption" : "Activează criptarea pe server",
    "Please read carefully before activating server-side encryption: " : "Citește cu atenție înainte să activezi criptarea pe server:",
    "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
    "Enable encryption" : "Activează criptarea",
    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
    "Start migration" : "Pornește migrarea",
    "Security & setup warnings" : "Alerte de securitate & configurare",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Modulul PHP \"Fileinfo\" lipsește. Va recomandam sa activaţi acest modul pentru a obține cele mai bune rezultate cu detectarea mime-type.",
    "All checks passed." : "Toate verificările s-au terminat fără erori.",
    "Cron" : "Cron",
    "Execute one task with each page loaded" : "Execută o sarcină la fiecare pagină încărcată",
    "Version" : "Versiunea",
    "Sharing" : "Partajare",
    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
    "Allow users to share via link" : "Permite utilizatorilor să partajeze via link",
    "Allow public uploads" : "Permite încărcări publice",
    "Enforce password protection" : "Impune protecția prin parolă",
    "Set default expiration date" : "Setează data implicită de expirare",
    "Expire after " : "Expiră după",
    "days" : "zile",
    "Enforce expiration date" : "Impune data de expirare",
    "Allow resharing" : "Permite repartajarea",
    "Allow sharing with groups" : "Permite partajarea cu grupuri",
    "Exclude groups from sharing" : "Exclude grupuri de la partajare",
    "Tips & tricks" : "Tips & tricks",
    "How to do backups" : "Cum să faci copii de rezervă",
    "Advanced monitoring" : "Monitorizare avansată",
    "Developer documentation" : "Documentație pentru dezvoltatori",
    "by %s" : "de %s",
    "%s-licensed" : "%s-licențiat",
    "Documentation:" : "Documentație:",
    "User documentation" : "Documentație utilizator",
    "Admin documentation" : "Documentație pentru administrare",
    "Report a bug" : "Raportează un defect",
    "Show description …" : "Arată descriere ...",
    "Hide description …" : "Ascunde descriere ...",
    "This app has an update available." : "Este disponibilă o actualizare pentru această aplicație.",
    "Enable only for specific groups" : "Activează doar pentru grupuri specifice",
    "Uninstall App" : "Dezinstalează aplicația",
    "SSL Root Certificates" : "Certificate SSL rădăcină",
    "Common Name" : "Nume comun",
    "Valid until" : "Valabil până la",
    "Issued By" : "Emis de",
    "Valid until %s" : "Valabil până la %s",
    "Import root certificate" : "Importă certificat rădăcină",
    "Cheers!" : "Noroc!",
    "Administrator documentation" : "Documentație pentru administrare",
    "Online documentation" : "Documentație online",
    "Forum" : "Forum",
    "Commercial support" : "Suport comercial",
    "Profile picture" : "Imagine de profil",
    "Upload new" : "Încarcă una nouă",
    "Remove image" : "Înlătură imagine",
    "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
    "Cancel" : "Anulare",
    "Full name" : "Nume complet",
    "Email" : "Email",
    "Your email address" : "Adresa ta de email",
    "Password" : "Parolă",
    "Current password" : "Parola curentă",
    "New password" : "Noua parolă",
    "Change password" : "Schimbă parola",
    "Language" : "Limba",
    "Help translate" : "Ajută la traducere",
    "Get the apps to sync your files" : "Ia acum aplicatia pentru sincronizarea fisierelor ",
    "Desktop client" : "Client Desktop",
    "Android app" : "Aplicatie Android",
    "iOS app" : "Aplicație iOS",
    "Name" : "Nume",
    "Username" : "Nume utilizator",
    "E-Mail" : "Email",
    "Create" : "Crează",
    "Admin Recovery Password" : "Parolă de recuperare a Administratorului",
    "Enter the recovery password in order to recover the users files during password change" : "Introdu parola de recuperare pentru a recupera fișierele utilizatorilor în timpul schimbării parolei",
    "Admins" : "Administratori",
    "Other" : "Altele",
    "Quota" : "Cotă",
    "change full name" : "schimbă numele complet",
    "set new password" : "setează parolă nouă",
    "change email address" : "schimbă adresa email",
    "Default" : "Implicită",
    "log-level out of allowed range" : "NIvelul de logare este în afara plajei admise",
    "Language changed" : "Limba a fost schimbată",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Tot (erori fatale, erori, avertizări, informări, depanare)",
    "Info, warnings, errors and fatal issues" : "Informări, avertizări, erori și erori fatale",
    "Warnings, errors and fatal issues" : "Avertizări, erori și erori fatale",
    "Errors and fatal issues" : "Erori și erori fatale",
    "Fatal issues only" : "Doar erori fatale",
    "Log" : "Jurnal de activitate",
    "What to log" : "Ce să loghezi",
    "Download logfile" : "Descarcă fișierul cu loguri",
    "More" : "Mai mult",
    "Less" : "Mai puțin",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Fișierul cu loguri este mai mare de 100 MB. Descărcarea acestuia ar putea dura ceva timp!",
    "Allow users to send mail notification for shared files" : "Permite utilizatorilor sa expedieze notificări prin e-mail pentru dosarele comune",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite e folosit ca o bază de date. Pentru instalări mari recomandăm folosirea unei alte baze de date.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "În special atunci când este folosit clientul desktop pentru sincronizarea fișierelor, utilizarea SQLite este nerecomandată.",
    "Enable experimental apps" : "Activează aplicațiile experimentale",
    "Group" : "Grup",
    "Redis" : "Redis",
    "External Storage" : "Stocare externă",
    "Updates" : "Actualizări",
    "An error occurred: {message}" : "A apărut o eroare: {message}"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-12.0.11.tar.bz2: nextcloud/settings/l10n/ro.js <==
OC.L10N.register(
    "settings",
    {
    "You changed your password" : "Ți-ai schimbat parola",
    "You changed your email address" : "Ți-ai schimbat adresa de email",
    "Your email address was changed by an administrator" : "Adresa ta de email a fost modificată de un administrator",
    "Security" : "Securitate",
    "Couldn't remove app." : "Nu s-a putut înlătura aplicația.",
    "Couldn't update app." : "Aplicaţia nu s-a putut actualiza.",
    "Wrong password" : "Parolă greșită",
    "Saved" : "Salvat",
    "No user supplied" : "Nu a fost furnizat niciun utilizator",
    "Unable to change password" : "Imposibil de schimbat parola",
    "Authentication error" : "Eroare la autentificare",
    "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
    "Federated Cloud Sharing" : "Partajare federalizata cloud",
    "Invalid SMTP password." : "Parolă SMTP invalidă.",
    "Email setting test" : "Test setări email",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
    "You need to set your user email before being able to send test emails." : "Trebuie să îți setezi emailul de utilizator înainte de a putea să trimiți emailuri.",
    "Invalid mail address" : "Adresa mail invalidă",
    "Unable to change full name" : "Nu s-a putut schimba numele complet",
    "Email address changed for %s" : "Adresa de email schimbată în %s",
    "The new email address is %s" : "Adresa de email nouă este%s",
    "Your %s account was created" : "Contul tău %s a fost creat",
    "Your username is: %s" : "Utilizatorul tău este: %s",
    "Set your password" : "Setează parola",
    "Install Client" : "Instalează client",
    "Migration in progress. Please wait until the migration is finished" : "Migrare în progres. Așteaptă până când migrarea este finalizată",
    "Migration started …" : "Migrarea a început...",
    "Not saved" : "Nu a fost salvat",
    "Sending…" : "Se trimite...",
    "Email sent" : "Mesajul a fost expediat",
    "Disconnect" : "Deconectare",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "iPhone iOS" : "iPhone iOS",
    "iPad iOS" : "iPad iOS",
    "iOS Client" : "iOS Client",
    "Android Client" : "Android Client",
    "Copy" : "Copiază",
    "Copied!" : "S-a copiat!",
    "Not supported!" : "Nu este suportat!",
    "Press ⌘-C to copy." : "Apasă ⌘-C pentru copiere.",
    "Press Ctrl-C to copy." : "Apasă Ctrl-C pentru copiere.",
    "Valid until {date}" : "Valabil până la {date}",
    "Delete" : "Șterge",
    "Contacts" : "Contacte",
    "Verify" : "Verifică",
    "Verifying …" : "Se verifică ...",
    "Very weak password" : "Parolă foarte slabă",
    "Weak password" : "Parolă slabă",
    "So-so password" : "Parolă medie",
    "Good password" : "Parolă bună",
    "Strong password" : "Parolă puternică",
    "Select a profile picture" : "Selectează o imagine de profil",
    "Groups" : "Grupuri",
    "Official" : "Oficial",
    "User documentation" : "Documentație utilizator",
    "Developer documentation" : "Documentație pentru dezvoltatori",
    "Enable" : "Activare",
    "The app will be downloaded from the app store" : "Aplicația va fi descărcată din magazin",
    "Settings" : "Setări",
    "Email" : "Email",
    "Language" : "Limba",
    "Unlimited" : "Nelimitată",
    "Your apps" : "Aplicațiile tale",
    "Disabled apps" : "Aplicații inactive",
    "Updates" : "Actualizări",
    "Admins" : "Administratori",
    "Everyone" : "Toți",
    "SSL Root Certificates" : "Certificate SSL rădăcină",
    "Common Name" : "Nume comun",
    "Valid until" : "Valabil până la",
    "Issued By" : "Emis de",
    "Valid until %s" : "Valabil până la %s",
    "Import root certificate" : "Importă certificat rădăcină",
    "Administrator documentation" : "Documentație pentru administrare",
    "Forum" : "Forum",
    "None" : "Niciuna",
    "Login" : "Autentificare",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Server de email",
    "Open documentation" : "Deschide documentația",
    "Send mode" : "Modul de expediere",
    "Encryption" : "Încriptare",
    "From address" : "De la adresa",
    "mail" : "poștă",
    "Authentication method" : "Modul de autentificare",
    "Authentication required" : "Autentificare necesară",
    "Server address" : "Adresa server-ului",
    "Port" : "Portul",
    "Credentials" : "Detalii de autentificare",
    "SMTP Username" : "Nume utilizator SMTP",
    "SMTP Password" : "Parolă SMTP",
    "Store credentials" : "Stochează datele de autentificare",
    "Test email settings" : "Verifică setările de e-mail",
    "Send email" : "Expediază mesajul",
    "Server-side encryption" : "Criptare la nivel de server",
    "Enable server-side encryption" : "Activează criptarea pe server",
    "Please read carefully before activating server-side encryption: " : "Citește cu atenție înainte să activezi criptarea pe server:",
    "This is the final warning: Do you really want to enable encryption?" : "Aceasta este avertizarea finală: Chiar vrei să activezi criptarea?",
    "Enable encryption" : "Activează criptarea",
    "Select default encryption module:" : "Selectează modulul implicit de criptare:",
    "Start migration" : "Pornește migrarea",
    "Security & setup warnings" : "Alerte de securitate & configurare",
    "All checks passed." : "Toate verificările s-au terminat fără erori.",
    "Version" : "Versiunea",
    "Execute one task with each page loaded" : "Execută o sarcină la fiecare pagină încărcată",
    "Sharing" : "Partajare",
    "Allow apps to use the Share API" : "Permite aplicațiilor să folosească API-ul de partajare",
    "Allow users to share via link" : "Permite utilizatorilor să partajeze via link",
    "Allow public uploads" : "Permite încărcări publice",
    "Enforce password protection" : "Impune protecția prin parolă",
    "Set default expiration date" : "Setează data implicită de expirare",
    "Expire after " : "Expiră după",
    "days" : "zile",
    "Enforce expiration date" : "Impune data de expirare",
    "Allow resharing" : "Permite repartajarea",
    "Allow sharing with groups" : "Permite partajarea cu grupuri",
    "Exclude groups from sharing" : "Exclude grupuri de la partajare",
    "Profile picture" : "Imagine de profil",
    "Upload new" : "Încarcă una nouă",
    "Select from Files" : "Selectează din fișiere",
    "Remove image" : "Înlătură imagine",
    "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
    "Cancel" : "Anulare",
    "Choose as profile picture" : "Alege ca imagine de profil",
    "Full name" : "Nume complet",
    "Your email address" : "Adresa ta de email",
    "Phone number" : "Număr telefon",
    "Your phone number" : "Numărul tău de telefon",
    "Address" : "Adresă",
    "Your postal address" : "Adresă poștală",
    "Website" : "Site web",
    "Link https://…" : "Link https://…",
    "Twitter" : "Twitter",
    "Help translate" : "Ajută la traducere",
    "Password" : "Parolă",
    "Current password" : "Parola curentă",
    "New password" : "Noua parolă",
    "Change password" : "Schimbă parola",
    "Device" : "Dispozitiv",
    "App name" : "Numele aplicației",
    "Username" : "Nume utilizator",
    "Enabled apps" : "Aplicații active",
    "Migration Completed" : "Migrare încheiată",
    "Group already exists." : "Grupul există deja.",
    "Unable to add group." : "Nu se poate adăuga grupul.",
    "Unable to delete group." : "Nu se poate șterge grupul.",
    "No valid group selected" : "Niciun grup valid selectat",
    "A user with that name already exists." : "Există deja un utilizator cu acest nume.",
    "Unable to create user." : "Imposibil de creat utilizatorul.",
    "Unable to delete user." : "Imposibil de șters utilizatorul.",
    "Error while enabling user." : "Eroare în timpul activării utilizatorului.",
    "Error while disabling user." : "Eroare în timpul dezactivării utilizatorului.",
    "Your full name has been changed." : "Numele tău complet a fost schimbat.",
    "Forbidden" : "Interzis",
    "Invalid user" : "Utilizator invalid",
    "Unable to change mail address" : "Nu s-a putut schimba adresa email",
    "Email saved" : "E-mail salvat",
    "Password confirmation is required" : "Confirmarea parolei este necesară",
    "Are you really sure you want add {domain} as trusted domain?" : "Ești sigur că vrei sa adaugi {domain} ca domeniu de încredere?",
    "Add trusted domain" : "Adaugă domeniu de încredere",
    "All" : "Toate ",
    "No apps found for your version" : "Nu au fost găsite aplicații pentru versiunea ta",
    "Error while disabling app" : "Eroare în timpul dezactivării aplicației",
    "Disable" : "Dezactivați",
    "Error while enabling app" : "Eroare în timpul activării applicației",
    "Updated" : "Actualizat",
    "Approved" : "Aprobat",
    "Experimental" : "Experimental",
    "Unable to delete {objName}" : "Nu s-a putut șterge {objName}",
    "Error creating group: {message}" : "Eroare la crearea grupului: {message}",
    "A valid group name must be provided" : "Trebuie furnizat un nume de grup valid",
    "deleted {groupName}" : "{groupName} s-a șters",
    "undo" : "Anulează ultima acțiune",
    "never" : "niciodată",
    "deleted {userName}" : "{userName} șters",
    "Add group" : "Adaugă grup",
    "Invalid quota value \"{val}\"" : "Valoare cotă invalidă \"{val}\"",
    "no group" : "niciun grup",
    "Password successfully changed" : "Parola a fost modificată cu succes.",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Schimbarea parolei va rezulta în pierderea datelor deoarece recuperarea acestora nu este disponibilă pentru acest utilizator",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "Error creating user: {message}" : "Eroare la crearea utilizatorului: {message}",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "A valid email must be provided" : "Trebuie furnizată o adresă email validă",
    "Tips & tricks" : "Tips & tricks",
    "How to do backups" : "Cum să faci copii de rezervă",
    "This app has an update available." : "Este disponibilă o actualizare pentru această aplicație.",
    "by %s" : "de %s",
    "%s-licensed" : "%s-licențiat",
    "Documentation:" : "Documentație:",
    "Admin documentation" : "Documentație pentru administrare",
    "Report a bug" : "Raportează un defect",
    "Show description …" : "Arată descriere ...",
    "Hide description …" : "Ascunde descriere ...",
    "Enable only for specific groups" : "Activează doar pentru grupuri specifice",
    "Online documentation" : "Documentație online",
    "Commercial support" : "Suport comercial",
    "E-Mail" : "Email",
    "Create" : "Crează",
    "Admin Recovery Password" : "Parolă de recuperare a Administratorului",
    "Enter the recovery password in order to recover the users files during password change" : "Introdu parola de recuperare pentru a recupera fișierele utilizatorilor în timpul schimbării parolei",
    "Disabled" : "Dezactivați",
    "Other" : "Altele",
    "Quota" : "Cotă",
    "change full name" : "schimbă numele complet",
    "set new password" : "setează parolă nouă",
    "change email address" : "schimbă adresa email",
    "Default" : "Implicită",
    "{size} used" : "{size} folosită"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
